import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DocDBElasticClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DocDBElasticClient";
import { GetPendingMaintenanceActionInput, GetPendingMaintenanceActionOutput } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetPendingMaintenanceActionCommand}.
 */
export interface GetPendingMaintenanceActionCommandInput extends GetPendingMaintenanceActionInput {
}
/**
 * @public
 *
 * The output of {@link GetPendingMaintenanceActionCommand}.
 */
export interface GetPendingMaintenanceActionCommandOutput extends GetPendingMaintenanceActionOutput, __MetadataBearer {
}
declare const GetPendingMaintenanceActionCommand_base: {
    new (input: GetPendingMaintenanceActionCommandInput): import("@smithy/smithy-client").CommandImpl<GetPendingMaintenanceActionCommandInput, GetPendingMaintenanceActionCommandOutput, DocDBElasticClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetPendingMaintenanceActionCommandInput): import("@smithy/smithy-client").CommandImpl<GetPendingMaintenanceActionCommandInput, GetPendingMaintenanceActionCommandOutput, DocDBElasticClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves all maintenance actions that are pending.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DocDBElasticClient, GetPendingMaintenanceActionCommand } from "@aws-sdk/client-docdb-elastic"; // ES Modules import
 * // const { DocDBElasticClient, GetPendingMaintenanceActionCommand } = require("@aws-sdk/client-docdb-elastic"); // CommonJS import
 * const client = new DocDBElasticClient(config);
 * const input = { // GetPendingMaintenanceActionInput
 *   resourceArn: "STRING_VALUE", // required
 * };
 * const command = new GetPendingMaintenanceActionCommand(input);
 * const response = await client.send(command);
 * // { // GetPendingMaintenanceActionOutput
 * //   resourcePendingMaintenanceAction: { // ResourcePendingMaintenanceAction
 * //     resourceArn: "STRING_VALUE",
 * //     pendingMaintenanceActionDetails: [ // PendingMaintenanceActionDetailsList
 * //       { // PendingMaintenanceActionDetails
 * //         action: "STRING_VALUE", // required
 * //         autoAppliedAfterDate: "STRING_VALUE",
 * //         forcedApplyDate: "STRING_VALUE",
 * //         optInStatus: "STRING_VALUE",
 * //         currentApplyDate: "STRING_VALUE",
 * //         description: "STRING_VALUE",
 * //       },
 * //     ],
 * //   },
 * // };
 *
 * ```
 *
 * @param GetPendingMaintenanceActionCommandInput - {@link GetPendingMaintenanceActionCommandInput}
 * @returns {@link GetPendingMaintenanceActionCommandOutput}
 * @see {@link GetPendingMaintenanceActionCommandInput} for command's `input` shape.
 * @see {@link GetPendingMaintenanceActionCommandOutput} for command's `response` shape.
 * @see {@link DocDBElasticClientResolvedConfig | config} for DocDBElasticClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>An exception that occurs when there are not sufficient permissions to perform an action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>There was an access conflict.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>There was an internal server error.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource could not be located.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>ThrottlingException will be thrown when request was denied due to request throttling.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>A structure defining a validation exception.</p>
 *
 * @throws {@link DocDBElasticServiceException}
 * <p>Base exception class for all service exceptions from DocDBElastic service.</p>
 *
 *
 * @public
 */
export declare class GetPendingMaintenanceActionCommand extends GetPendingMaintenanceActionCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetPendingMaintenanceActionInput;
            output: GetPendingMaintenanceActionOutput;
        };
        sdk: {
            input: GetPendingMaintenanceActionCommandInput;
            output: GetPendingMaintenanceActionCommandOutput;
        };
    };
}
