import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DocDBElasticServiceException as __BaseException } from "./DocDBElasticServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare const OptInType: {
  readonly APPLY_ON: "APPLY_ON";
  readonly IMMEDIATE: "IMMEDIATE";
  readonly NEXT_MAINTENANCE: "NEXT_MAINTENANCE";
  readonly UNDO_OPT_IN: "UNDO_OPT_IN";
};
export type OptInType = (typeof OptInType)[keyof typeof OptInType];
export interface ApplyPendingMaintenanceActionInput {
  resourceArn: string | undefined;
  applyAction: string | undefined;
  optInType: OptInType | undefined;
  applyOn?: string | undefined;
}
export interface PendingMaintenanceActionDetails {
  action: string | undefined;
  autoAppliedAfterDate?: string | undefined;
  forcedApplyDate?: string | undefined;
  optInStatus?: string | undefined;
  currentApplyDate?: string | undefined;
  description?: string | undefined;
}
export interface ResourcePendingMaintenanceAction {
  resourceArn?: string | undefined;
  pendingMaintenanceActionDetails?:
    | PendingMaintenanceActionDetails[]
    | undefined;
}
export interface ApplyPendingMaintenanceActionOutput {
  resourcePendingMaintenanceAction:
    | ResourcePendingMaintenanceAction
    | undefined;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  resourceId: string | undefined;
  resourceType: string | undefined;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  $retryable: {};
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  resourceId: string | undefined;
  resourceType: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  $retryable: {};
  retryAfterSeconds?: number | undefined;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export interface ValidationExceptionField {
  name: string | undefined;
  message: string | undefined;
}
export declare const ValidationExceptionReason: {
  readonly CANNOT_PARSE: "cannotParse";
  readonly FIELD_VALIDATION_FAILED: "fieldValidationFailed";
  readonly OTHER: "other";
  readonly UNKNOWN_OPERATION: "unknownOperation";
};
export type ValidationExceptionReason =
  (typeof ValidationExceptionReason)[keyof typeof ValidationExceptionReason];
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  reason: ValidationExceptionReason | undefined;
  fieldList?: ValidationExceptionField[] | undefined;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export declare const Auth: {
  readonly PLAIN_TEXT: "PLAIN_TEXT";
  readonly SECRET_ARN: "SECRET_ARN";
};
export type Auth = (typeof Auth)[keyof typeof Auth];
export interface CopyClusterSnapshotInput {
  snapshotArn: string | undefined;
  targetSnapshotName: string | undefined;
  kmsKeyId?: string | undefined;
  copyTags?: boolean | undefined;
  tags?: Record<string, string> | undefined;
}
export declare const SnapshotType: {
  readonly AUTOMATED: "AUTOMATED";
  readonly MANUAL: "MANUAL";
};
export type SnapshotType = (typeof SnapshotType)[keyof typeof SnapshotType];
export declare const Status: {
  readonly ACTIVE: "ACTIVE";
  readonly COPYING: "COPYING";
  readonly CREATING: "CREATING";
  readonly DELETING: "DELETING";
  readonly INACCESSIBLE_ENCRYPTION_CREDENTIALS_RECOVERABLE: "INACCESSIBLE_ENCRYPTION_CREDENTIALS_RECOVERABLE";
  readonly INACCESSIBLE_ENCRYPTION_CREDS: "INACCESSIBLE_ENCRYPTION_CREDS";
  readonly INACCESSIBLE_SECRET_ARN: "INACCESSIBLE_SECRET_ARN";
  readonly INACCESSIBLE_VPC_ENDPOINT: "INACCESSIBLE_VPC_ENDPOINT";
  readonly INCOMPATIBLE_NETWORK: "INCOMPATIBLE_NETWORK";
  readonly INVALID_SECURITY_GROUP_ID: "INVALID_SECURITY_GROUP_ID";
  readonly INVALID_SUBNET_ID: "INVALID_SUBNET_ID";
  readonly IP_ADDRESS_LIMIT_EXCEEDED: "IP_ADDRESS_LIMIT_EXCEEDED";
  readonly MAINTENANCE: "MAINTENANCE";
  readonly MERGING: "MERGING";
  readonly MODIFYING: "MODIFYING";
  readonly SPLITTING: "SPLITTING";
  readonly STARTING: "STARTING";
  readonly STOPPED: "STOPPED";
  readonly STOPPING: "STOPPING";
  readonly UPDATING: "UPDATING";
  readonly VPC_ENDPOINT_LIMIT_EXCEEDED: "VPC_ENDPOINT_LIMIT_EXCEEDED";
};
export type Status = (typeof Status)[keyof typeof Status];
export interface ClusterSnapshot {
  subnetIds: string[] | undefined;
  snapshotName: string | undefined;
  snapshotArn: string | undefined;
  snapshotCreationTime: string | undefined;
  clusterArn: string | undefined;
  clusterCreationTime: string | undefined;
  status: Status | undefined;
  vpcSecurityGroupIds: string[] | undefined;
  adminUserName: string | undefined;
  kmsKeyId: string | undefined;
  snapshotType?: SnapshotType | undefined;
}
export interface CopyClusterSnapshotOutput {
  snapshot: ClusterSnapshot | undefined;
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface CreateClusterInput {
  clusterName: string | undefined;
  authType: Auth | undefined;
  adminUserName: string | undefined;
  adminUserPassword: string | undefined;
  shardCapacity: number | undefined;
  shardCount: number | undefined;
  vpcSecurityGroupIds?: string[] | undefined;
  subnetIds?: string[] | undefined;
  kmsKeyId?: string | undefined;
  clientToken?: string | undefined;
  preferredMaintenanceWindow?: string | undefined;
  tags?: Record<string, string> | undefined;
  backupRetentionPeriod?: number | undefined;
  preferredBackupWindow?: string | undefined;
  shardInstanceCount?: number | undefined;
}
export interface Shard {
  shardId: string | undefined;
  createTime: string | undefined;
  status: Status | undefined;
}
export interface Cluster {
  clusterName: string | undefined;
  clusterArn: string | undefined;
  status: Status | undefined;
  clusterEndpoint: string | undefined;
  createTime: string | undefined;
  adminUserName: string | undefined;
  authType: Auth | undefined;
  shardCapacity: number | undefined;
  shardCount: number | undefined;
  vpcSecurityGroupIds: string[] | undefined;
  subnetIds: string[] | undefined;
  preferredMaintenanceWindow: string | undefined;
  kmsKeyId: string | undefined;
  shards?: Shard[] | undefined;
  backupRetentionPeriod?: number | undefined;
  preferredBackupWindow?: string | undefined;
  shardInstanceCount?: number | undefined;
}
export interface CreateClusterOutput {
  cluster: Cluster | undefined;
}
export interface CreateClusterSnapshotInput {
  clusterArn: string | undefined;
  snapshotName: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface CreateClusterSnapshotOutput {
  snapshot: ClusterSnapshot | undefined;
}
export interface DeleteClusterInput {
  clusterArn: string | undefined;
}
export interface DeleteClusterOutput {
  cluster: Cluster | undefined;
}
export interface DeleteClusterSnapshotInput {
  snapshotArn: string | undefined;
}
export interface DeleteClusterSnapshotOutput {
  snapshot: ClusterSnapshot | undefined;
}
export interface GetClusterInput {
  clusterArn: string | undefined;
}
export interface GetClusterOutput {
  cluster: Cluster | undefined;
}
export interface GetClusterSnapshotInput {
  snapshotArn: string | undefined;
}
export interface GetClusterSnapshotOutput {
  snapshot: ClusterSnapshot | undefined;
}
export interface GetPendingMaintenanceActionInput {
  resourceArn: string | undefined;
}
export interface GetPendingMaintenanceActionOutput {
  resourcePendingMaintenanceAction:
    | ResourcePendingMaintenanceAction
    | undefined;
}
export interface ListClustersInput {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ClusterInList {
  clusterName: string | undefined;
  clusterArn: string | undefined;
  status: Status | undefined;
}
export interface ListClustersOutput {
  clusters?: ClusterInList[] | undefined;
  nextToken?: string | undefined;
}
export interface ListClusterSnapshotsInput {
  clusterArn?: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
  snapshotType?: string | undefined;
}
export interface ClusterSnapshotInList {
  snapshotName: string | undefined;
  snapshotArn: string | undefined;
  clusterArn: string | undefined;
  status: Status | undefined;
  snapshotCreationTime: string | undefined;
}
export interface ListClusterSnapshotsOutput {
  snapshots?: ClusterSnapshotInList[] | undefined;
  nextToken?: string | undefined;
}
export interface ListPendingMaintenanceActionsInput {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListPendingMaintenanceActionsOutput {
  resourcePendingMaintenanceActions:
    | ResourcePendingMaintenanceAction[]
    | undefined;
  nextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  resourceArn: string | undefined;
}
export interface ListTagsForResourceResponse {
  tags?: Record<string, string> | undefined;
}
export interface RestoreClusterFromSnapshotInput {
  clusterName: string | undefined;
  snapshotArn: string | undefined;
  vpcSecurityGroupIds?: string[] | undefined;
  subnetIds?: string[] | undefined;
  kmsKeyId?: string | undefined;
  tags?: Record<string, string> | undefined;
  shardCapacity?: number | undefined;
  shardInstanceCount?: number | undefined;
}
export interface RestoreClusterFromSnapshotOutput {
  cluster: Cluster | undefined;
}
export interface StartClusterInput {
  clusterArn: string | undefined;
}
export interface StartClusterOutput {
  cluster: Cluster | undefined;
}
export interface StopClusterInput {
  clusterArn: string | undefined;
}
export interface StopClusterOutput {
  cluster: Cluster | undefined;
}
export interface TagResourceRequest {
  resourceArn: string | undefined;
  tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateClusterInput {
  clusterArn: string | undefined;
  authType?: Auth | undefined;
  shardCapacity?: number | undefined;
  shardCount?: number | undefined;
  vpcSecurityGroupIds?: string[] | undefined;
  subnetIds?: string[] | undefined;
  adminUserPassword?: string | undefined;
  clientToken?: string | undefined;
  preferredMaintenanceWindow?: string | undefined;
  backupRetentionPeriod?: number | undefined;
  preferredBackupWindow?: string | undefined;
  shardInstanceCount?: number | undefined;
}
export interface UpdateClusterOutput {
  cluster: Cluster | undefined;
}
export declare const CreateClusterInputFilterSensitiveLog: (
  obj: CreateClusterInput
) => any;
export declare const UpdateClusterInputFilterSensitiveLog: (
  obj: UpdateClusterInput
) => any;
